@@ -89,7 +89,7 @@ class Client(object):
         if not status_string:
             raise Snap7Exception("The cpu state (%s) is invalid" % state.value)
         
-        logging.debug("CPU state is %s" % status_string)
+        logger.debug("CPU state is %s" % status_string)
         return status_string
 
     def get_cpu_info(self):
@@ -153,12 +153,23 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         size = len(data)
-        cdata = (type_ * size).from_buffer(data)
+        cdata = (type_ * size).from_buffer_copy(data)
         logger.debug("db_write db_number:%s start:%s size:%s data:%s" %
                      (db_number, start, size, data))
         return self.library.Cli_DBWrite(self.pointer, db_number, start, size,
                                         byref(cdata))
-
+    def delete(self, block_type, block_num):
+        """
+        Deletes a block
+        
+        :param block_type: Type of block
+        :param block_num: Bloc number
+        """
+        logger.info("deleting block")
+        blocktype = snap7.snap7types.block_types[block_type]
+        result = self.library.Cli_Delete(self.pointer, blocktype, block_num)
+        return result
+      
     def full_upload(self, _type, block_num):
         """
         Uploads a full block body from AG.
@@ -207,7 +218,7 @@ class Client(object):
         """
         type_ = c_byte
         size = len(data)
-        cdata = (type_ * len(data)).from_buffer(data)
+        cdata = (type_ * len(data)).from_buffer_copy(data)
         result = self.library.Cli_Download(self.pointer, block_num,
                                            byref(cdata), size)
         return result
@@ -215,7 +226,7 @@ class Client(object):
     def db_get(self, db_number):
         """Uploads a DB from AG.
         """
-        logging.debug("db_get db_number: %s" % db_number)
+        logger.debug("db_get db_number: %s" % db_number)
         _buffer = buffer_type()
         result = self.library.Cli_DBGet(
             self.pointer, db_number, byref(_buffer),
@@ -234,7 +245,7 @@ class Client(object):
         assert area in snap7.snap7types.areas.values()
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
-        logging.debug("reading area: %s dbnumber: %s start: %s: amount %s: "
+        logger.debug("reading area: %s dbnumber: %s start: %s: amount %s: "
                       "wordlen: %s" % (area, dbnumber, start, size, wordlen))
         data = (type_ * size)()
         result = self.library.Cli_ReadArea(self.pointer, area, dbnumber, start,
@@ -256,9 +267,9 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         size = len(data)
-        logging.debug("writing area: %s dbnumber: %s start: %s: size %s: "
+        logger.debug("writing area: %s dbnumber: %s start: %s: size %s: "
                       "type: %s" % (area, dbnumber, start, size, type_))
-        cdata = (type_ * len(data)).from_buffer(data)
+        cdata = (type_ * len(data)).from_buffer_copy(data)
         return self.library.Cli_WriteArea(self.pointer, area, dbnumber, start,
                                           size, wordlen, byref(cdata))
 
@@ -278,11 +289,11 @@ class Client(object):
 
         :returns: a snap7.types.BlocksList object.
         """
-        logging.debug("listing blocks")
+        logger.debug("listing blocks")
         blocksList = BlocksList()
         result = self.library.Cli_ListBlocks(self.pointer, byref(blocksList))
         check_error(result, context="client")
-        logging.debug("blocks: %s" % blocksList)
+        logger.debug("blocks: %s" % blocksList)
         return blocksList
 
     def list_blocks_of_type(self, blocktype, size):
@@ -293,7 +304,7 @@ class Client(object):
         if not blocktype:
             raise Snap7Exception("The blocktype parameter was invalid")
 
-        logging.debug("listing blocks of type: %s size: %s" %
+        logger.debug("listing blocks of type: %s size: %s" %
                       (blocktype, size))
 
         if (size == 0):
@@ -306,7 +317,7 @@ class Client(object):
             byref(data),
             byref(count))
 
-        logging.debug("number of items found: %s" % count)
+        logger.debug("number of items found: %s" % count)
 
         check_error(result, context="client")
         return data
@@ -319,7 +330,7 @@ class Client(object):
         if not blocktype:
             raise Snap7Exception("The blocktype parameter was invalid")
 
-        logging.debug("retrieving block info for block %s of type %s" %
+        logger.debug("retrieving block info for block %s of type %s" %
                       (db_number, blocktype))
 
         data = TS7BlockInfo()
@@ -388,7 +399,7 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         data = (type_ * size)()
-        logging.debug("ab_read: start: %s: size %s: " % (start, size))
+        logger.debug("ab_read: start: %s: size %s: " % (start, size))
         result = self.library.Cli_ABRead(self.pointer, start, size,
                                          byref(data))
         check_error(result, context="client")
@@ -402,8 +413,8 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         size = len(data)
-        cdata = (type_ * size).from_buffer(data)
-        logging.debug("ab write: start: %s: size: %s: " % (start, size))
+        cdata = (type_ * size).from_buffer_copy(data)
+        logger.debug("ab write: start: %s: size: %s: " % (start, size))
         return self.library.Cli_ABWrite(
             self.pointer, start, size, byref(cdata))
 
@@ -414,7 +425,7 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         data = (type_ * size)()
-        logging.debug("ab_read: start: %s: size %s: " % (start, size))
+        logger.debug("ab_read: start: %s: size %s: " % (start, size))
         result = self.library.Cli_AsABRead(self.pointer, start, size,
                                            byref(data))
         check_error(result, context="client")
@@ -427,8 +438,8 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         size = len(data)
-        cdata = (type_ * size).from_buffer(data)
-        logging.debug("ab write: start: %s: size: %s: " % (start, size))
+        cdata = (type_ * size).from_buffer_copy(data)
+        logger.debug("ab write: start: %s: size: %s: " % (start, size))
         return self.library.Cli_AsABWrite(
             self.pointer, start, size, byref(cdata))
 
@@ -467,7 +478,7 @@ class Client(object):
         """
         This is the asynchronous counterpart of Cli_DBGet.
         """
-        logging.debug("db_get db_number: %s" % db_number)
+        logger.debug("db_get db_number: %s" % db_number)
         _buffer = buffer_type()
         result = self.library.Cli_AsDBGet(self.pointer, db_number,
                                           byref(_buffer),
@@ -498,7 +509,7 @@ class Client(object):
         wordlen = snap7.snap7types.S7WLByte
         type_ = snap7.snap7types.wordlen_to_ctypes[wordlen]
         size = len(data)
-        cdata = (type_ * size).from_buffer(data)
+        cdata = (type_ * size).from_buffer_copy(data)
         logger.debug("db_write db_number:%s start:%s size:%s data:%s" %
                      (db_number, start, size, data))
         return self.library.Cli_AsDBWrite(
@@ -517,7 +528,7 @@ class Client(object):
         """
         size = len(data)
         type_ = c_byte * len(data)
-        cdata = type_.from_buffer(data)
+        cdata = type_.from_buffer_copy(data)
         return self.library.Cli_AsDownload(self.pointer, block_num,
                                            byref(cdata), size)
 
