@@ -135,7 +135,7 @@ def set_int(_bytearray, byte_index, _int):
     # make sure were dealing with an int
     _int = int(_int)
     _bytes = struct.unpack('2B', struct.pack('>h', _int))
-    _bytearray[byte_index:2] = _bytes
+    _bytearray[byte_index:byte_index + 2] = _bytes
 
 
 def get_int(_bytearray, byte_index):
@@ -144,7 +144,7 @@ def get_int(_bytearray, byte_index):
 
     int are represented in two bytes
     """
-    data = _bytearray[byte_index:2]
+    data = _bytearray[byte_index:byte_index + 2]
     value = struct.unpack('>h', struct.pack('2B', *data))[0]
     return value
 
@@ -208,8 +208,8 @@ def get_string(_bytearray, byte_index, max_size):
     size = _bytearray[byte_index + 1]
 
     if max_size < size:
-        logging.error("the string is to big for the size encountered in specification")
-        logging.error("WRONG SIZED STRING ENCOUNTERED")
+        logger.error("the string is to big for the size encountered in specification")
+        logger.error("WRONG SIZED STRING ENCOUNTERED")
         size = max_size
 
     data = map(chr, _bytearray[byte_index + 2:byte_index + 2 + size])
@@ -311,7 +311,7 @@ class DB(object):
             key = row[id_field] if id_field else i
             if key and key in self.index:
                 msg = '%s not unique!' % key
-                logging.error(msg)
+                logger.error(msg)
             self.index[key] = row
 
     def __getitem__(self, key, default=None):
